==> 0.1.31.tar.gz: lib/src/cloud_models/cloud_connected_tool_recommendation.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'cloud_connected_tool_recommendation.g.dart';

@JsonSerializable(explicitToJson: true)
class CloudConnectedToolRecommendation {
  String? pluginId;
  String? pluginName;
  String? recommendationId;
  String? recommendationType;
  String? shortDescription;
  String? longDescription;
  String? action;
  List<String>? relatedThreatsWeights;
  String? costs;

  CloudConnectedToolRecommendation({
      this.pluginId,
      this.pluginName,
      this.recommendationId,
      this.recommendationType,
      this.shortDescription,
      this.longDescription,
      this.action,
      this.relatedThreatsWeights,
      this.costs
  });

  factory CloudConnectedToolRecommendation.fromJson(Map<String,dynamic> json) => _$CloudConnectedToolRecommendationFromJson(json);

  Map<String, dynamic> toJson() => _$CloudConnectedToolRecommendationToJson(this);

  String? get getPluginId => pluginId;
  set setPluginId(String pluginId) => this.pluginId = pluginId;

  String? get getPluginName => pluginName;
  set setPluginName(String pluginName) => this.pluginName = pluginName;

  String? get getRecommendationId => recommendationId;
  set setRecommendationId(String recommendationId) => this.recommendationId = recommendationId;

  String? get getRecommendationType => recommendationType;
  set setRecommendationType(String recommendationType) => this.recommendationType = recommendationType;

  String? get getShortDescription => shortDescription;
  set setShortDescription(String shortDescription) => this.shortDescription = shortDescription;

  String? get getLongDescription => longDescription;
  set setLongDescription(String longDescription) => this.longDescription = longDescription;

  String? get getAction => action;
  set setAction(String action) => this.action = action;

  List<String>? get getRelatedThreatsWeights => relatedThreatsWeights;
  set setRelatedThreatsWeights(List<String> values) => this.relatedThreatsWeights = values;

  String? get getCosts => costs;
  set setCosts(String costs) => this.costs = costs;

}

==> 0.1.38.tar.gz: lib/src/cloud_models/cloud_connected_tool_recommendation.dart <==
import 'package:json_annotation/json_annotation.dart';

part 'cloud_connected_tool_recommendation.g.dart';

@JsonSerializable(explicitToJson: true)
class CloudConnectedToolRecommendation {
  String? pluginId;
  String? pluginName;
  String? recommendationId;
  String? recommendationType;
  String? shortDescription;
  String? longDescription;
  String? action;
  List<String>? relatedThreatsWeights;
  String? costs;

  CloudConnectedToolRecommendation(
      {this.pluginId,
      this.pluginName,
      this.recommendationId,
      this.recommendationType,
      this.shortDescription,
      this.longDescription,
      this.action,
      this.relatedThreatsWeights,
      this.costs});

  factory CloudConnectedToolRecommendation.fromJson(
          Map<String, dynamic> json) =>
      _$CloudConnectedToolRecommendationFromJson(json);

  Map<String, dynamic> toJson() =>
      _$CloudConnectedToolRecommendationToJson(this);

  String? get getPluginId => pluginId;
  set setPluginId(String pluginId) => this.pluginId = pluginId;

  String? get getPluginName => pluginName;
  set setPluginName(String pluginName) => this.pluginName = pluginName;

  String? get getRecommendationId => recommendationId;
  set setRecommendationId(String recommendationId) =>
      this.recommendationId = recommendationId;

  String? get getRecommendationType => recommendationType;
  set setRecommendationType(String recommendationType) =>
      this.recommendationType = recommendationType;

  String? get getShortDescription => shortDescription;
  set setShortDescription(String shortDescription) =>
      this.shortDescription = shortDescription;

  String? get getLongDescription => longDescription;
  set setLongDescription(String longDescription) =>
      this.longDescription = longDescription;

  String? get getAction => action;
  set setAction(String action) => this.action = action;

  List<String>? get getRelatedThreatsWeights => relatedThreatsWeights;
  set setRelatedThreatsWeights(List<String> values) =>
      this.relatedThreatsWeights = values;

  String? get getCosts => costs;
  set setCosts(String costs) => this.costs = costs;
}
